@@ -105,7 +105,7 @@ SEQMAP_VALUE* seqmap_fetch(unsigned int id, int64_t now)
 {
     SEQMAP_VALUE* value;
 
-    if (id > SEQMAP_MAXSEQ) {
+    if (id >= SEQMAP_MAXSEQ) {
         return NULL;
     }
 
